ADA documentation — ADA 1.0.3 documentation

Skip to main content
`Ctrl`+`K`

# ADA documentation

ADA stands for Actigraphic Data Analyzer, coincidentally being also the name of the first programmer in the world. It is an open source Python module for processing, analyzing and visualizing actigraphic data, with the main focus on bedtime sleep/wake classification and circadian rhythms analysis. When using ADA please cite

Accompanying publication

IT WILL BE THERE

ADA requires Python 3.11 or higher. You can install package via `pip`:

    pip install acti-data-analyzer

The source code is also available on GitLab under the link.

Contents:

- Quickstart
  - Data loading and epoching
  - Example of sleep scoring
  - Example of long fitting
  - Operating on PSG and actigraphic recordings
- Data types
  - Actigraphic data
  - Actigraphy with PSG
  - Long Results
  - MESA dataset
  - ADA formats specification
- ADA Graphical Interface Tutorial
  - Analysis walkthrough
  - Presets and pipeline
  - Settings and help
- API Reference
  - ada